#!/usr/bin/perl
use lib '.';
use BlueRoseChar;
use CGI;
use FileHandle;
use strict;

my $req = new CGI;

my $shortname = $req->param("shortname");
my $char;
if (defined($shortname) and (-e "$shortname.txt")) {
    $char = BlueRoseChar->getChar($shortname);
} else {
    $char = BlueRoseChar->new();
}

# If there are input parameters, read them into the file
if ($req->param() > 5) {
    foreach my $key ($req->param()) {
	my $value = join('',$req->param($key));
        $char->$key( $value );
    }
    $char->validate();
    # now write out the stats
    if (defined($shortname)) {
	$char->writeFile();
    } else {
	$char->writeFile("last.txt");
    }
}

if ($req->param("style") eq "xml") {
    print_xml_style($char,$req);
} else {
    print_default_style($char,$req);
}

########################################################################
sub print_default_style {
    my ($char,$req) = @_;
    # create hidden fields for all stats
    my $hidden;
    foreach ($char->stats()) {
	$hidden .= "<input type=\"hidden\" name=\"$_\" value=\"$char->{$_}\">\n";
    }
    # compress the skill list to exclude non-known skills
    $char->shortenSkills();
    # add line breaks to possibly-formatted fields
    $char->{'Feats'} =~ s/\n/<br>\n/gs;
    $char->{'Arcana'} =~ s/\n/<br>\n/gs;
    $char->{'SpecialAbilities'} =~ s/\n/<br>\n/gs;
    $char->{'Equipment'} =~ s/\n/<br>\n/gs;

    print $req->header();
print <<EndDefaultDocument;
<html> <head>
<title>Blue Rose Character Sheet</title>
<style type="text/css">
table.standard {
    padding-right: 0px; padding-left: 0px;
    padding-bottom: 0px; padding-top: 0px;
    text-align: center; 
    font-weight: normal; font-size: 7pt;
    font-family:  Verdana, Arial, Helvetica, sans-serif;
}
.subtitleHeading {
    font-weight: bold; font-size: 8pt;
    font-family: "Times New Roman",Times,Serif;
}
.majorHeading {
    background-color:  #000000;
    color:             #ffffff;
    font-weight: bold; font-size: 7pt;
    font-family:  Verdana, Arial, Helvetica, sans-serif;
}
.minorHeading {
    background-color:  #000000;
    color:             #ffffff;
    font-weight: bold; font-size: 8pt;
    font-family: "Times New Roman",Times,Serif;
}
.statHeading {
    background-color:  #cccccc;
    color:             #000000;
    font-weight: bold; font-size: 7pt;
    font-family: "Times New Roman",Times,Serif;
}
</style>

</head>

<body bgcolor="white" leftmargin="0" marginwidth="0" topmargin="0" marginheight="0">
<!-- start of whole-page five-column table -->
<!--  | 45  |15|            480                  |15|  45 |  -->
<!--  +-----+--+---------------------------------+--+-----+  -->
<!--  |     |  | spacer cell (height 24)         |  |     |  -->
<!--  |     |  |---------------------------------|  |     |  -->
<!--  |     |  | name/title subtable             |  |     |  -->
<!--  | lft |  |---------------------------------|  | rt  |  -->
<!--  | bor |  | history/description subtable    |  | bor |  -->
<!--  | der |  |---------------------------------|  | der |  -->
<!--  |     |  | stats(75+40+105+40+75+40+65+40) |  |     |  -->
<!--  |     |  |---------------------------------|  |     |  -->
<!--  |     |  | weapons subtable                |  |     |  -->
<!--  |     |  |---------------------------------|  |     |  -->
<!--  |     |  | skills subtable                 |  |     |  -->
<!--  |     |  |---------------------------------|  |     |  -->
<!--  |     |  | arcana/feats/etc subtable       |  |     |  -->
<!--  +-----+--+---------------------------------+--+-----+  -->

<form method="POST" action="http://www.darkshire.net/~jhkim/rpg/bluerose/chars/edit.cgi">
$hidden
</form>

<table class="standard" border="0" width="600" cellpadding="0" cellspacing="0">
<tr>
  <td rowspan="7" width="45" align="left" valign="top">
    <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/border_left_thin.jpg" width="45" height="782">
  </td>
  <td rowspan="7" width="15" align="center"> &nbsp; </td>
  <td width="480" height="6" align="center"></td>
  <td rowspan="7" width="15" align="center"> &nbsp; </td>
  <td rowspan="7" width="45" align="right" valign="top">
    <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/border_right_thin.jpg" width="45" height="782">
  </td>
</tr>
<tr>
  <td width="480" align="center">
    <!-- start of name/title subtable -->
    <table class="standard" width="480" border="0" cellpadding="0" cellspacing="0">
    <tr>
      <td colspan="2" width="235" height="1" bgcolor="#000000"></td>
      <td rowspan="7" width="245" height="58" align="right">
        <a href="edit.cgi" onClick="document.forms[0].submit();return false;">
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/blue_rose_logo.jpg" width="240" height="58"></a>
      </td>
    </tr>
    <tr>
      <td class="majorHeading" width="95" height="18" align="center">
        <big>N</big>AME </td>
      <td width="140" height="18" border="1" align="center"> 
$char->{'CharacterName'}
      </td>
    </tr>
    <tr>
      <td colspan="2" width="235" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <td class="majorHeading" width="95" height="18" align="center">
        <big>B</big>ACKGROUND </td>
      <td width="140" height="18" border="1" align="center">
$char->{'CharacterBackground'}
      </td>
    </tr>
    <tr>
      <td colspan="2" width="235" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <td class="majorHeading" width="95" height="18" align="center">
        <big>R</big>OLE </td>
      <td width="140" height="18" border="1" align="center">
$char->{'CharacterRole'}
      </td>
    </tr>
    <tr>
      <td colspan="2" width="235" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <td class="majorHeading" width="95" height="18" align="center">
        <big>L</big>EVEL </td>
      <td width="140" height="18" border="1" align="center">
$char->{'CharacterLevel'}
      </td>
      <td class="subtitleHeading" width="245" height="18" border="0" align="center">
        The Roleplaying Game of Romantic Fantasy
      </td>
    </tr>
    </table>
    <!-- end of name/title subtable -->
  </td>
</tr>
<tr>
  <td width="480" align="center">
    <!-- start of history/description subtable -->
    <table class="standard" width="480" border="0" cellpadding="0" cellspacing="0">
    <tr>
      <td class="majorHeading" height="18" align="center">
        <big>H</big>ISTORY </td>
    </tr>
    <tr>
      <td height="40" align="left" valign="top">
$char->{'History'}
      </td>
    </tr>
    <tr>
      <td class="majorHeading" height="18" align="center">
        <big>D</big>ESCRIPTION </td>
    </tr>
    <tr>
      <td height="30" align="left" valign="top">
$char->{'Description'}
      </td>
    </tr>
    </table>
    <!-- end of history/description subtable -->
  </td>
</tr>
<tr>
  <td width="480" align="center">
    <!-- start of statistics subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="0">
    <tr>
      <td colspan="16" class="majorHeading" width="480" height="18" align="center">
        <big>S</big>TATISTICS </td>
    </tr>
    <tr>
      <td colspan="4" class="minorHeading" width="115" height="14" align="center">
        Abilities </td>
      <td colspan="4" class="minorHeading" width="145" height="14" align="center">
        Combat </td>
      <td colspan="4" class="minorHeading" width="115" height="14" align="center">
        Saving Throws </td>
      <td colspan="4" class="minorHeading" width="105" height="14" align="center">
        Other Statistics </td>
    </tr>
    <tr>
      <td class="statHeading" width="74" height="14" align="center">
        Strength </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Ability_Strength_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="104" height="14" align="center">
        Initiative </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Initiative'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Toughness </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'SavingThrow_Toughness_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="64" height="14" align="center">
        Size </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Size'} </td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="16" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td class="statHeading" width="74" height="14" align="center">
        Dexterity </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Ability_Dexterity_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="104" height="14" align="center">
        Defense </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Defense'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Fortitude </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'SavingThrow_Fortitude_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="64" height="14" align="center">
        Speed </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Speed'} </td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="16" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td class="statHeading" width="74" height="14" align="center">
        Constitution </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Ability_Constitution_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="104" height="14" align="center">
        Base Attack Bonus </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'BaseAttackBonus'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Reflex </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'SavingThrow_Reflex_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="4" width="105" height="14" border="0" align="center"> &nbsp; </td>
    </tr>
    <tr>
      <td colspan="12" bgcolor="#000000" height="1"></td>
      <td colspan="4" bgcolor="#FFFFFF" height="1"></td>
    </tr>
    <tr>
      <td class="statHeading" width="74" height="14" align="center">
        Intelligence </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Ability_Intelligence_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="104" height="14" align="center">
        Melee Attack Bonus </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'MeleeAttackBonus'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Will </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'SavingThrow_Will_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="4" width="105" height="14" border="0" align="center"> &nbsp; </td>
    </tr>
    <tr>
      <td colspan="16" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td class="statHeading" width="74" height="14" align="center">
        Wisdom </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Ability_Wisdom_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="104" height="14" align="center">
        Ranged Attack Bonus </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'RangedAttackBonus'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="8" class="minorHeading" width="220" height="14" align="center">
        Characteristics
      </td>
    </tr>
    <tr>
      <td colspan="16" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td class="statHeading" width="74" height="14" align="center">
        Charisma </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="center"> $char->{'Ability_Charisma_Value'} </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="3" width="144" height="14" border="0" align="center"> &nbsp; </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Conviction </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" align="center">$char->{'Conviction'}&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7"></td>
    </tr>
    <tr>
      <td colspan="4" bgcolor="#000000" height="1"></td>
      <td colspan="3" bgcolor="#FFFFFF" height="1"></td>
      <td colspan="9" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td colspan="7" width="259" height="14" border="0" align="center"> &nbsp; </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Corruption </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" align="center">$char->{'Corruption'}&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7">&nbsp;<img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox.gif" width="7" height="7"></td>
    </tr>
    <tr>
      <td colspan="7" bgcolor="#FFFFFF" height="1"></td>
      <td colspan="9" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td rowspan="13" colspan="7" width="259" height="14" valign="bottom">
<!-- start of Damage Track subtable -->
<table class="standard" width="100%" border="0" cellpadding="0" cellspacing="0">
<tr>
  <td class="majorHeading" colspan="5" height="18" align="center">
    <big>D</big>AMAGE <big>T</big>RACK
  </td>
</tr>
<tr>
  <td width="52" height="18" align="center"> 0-4 </td>
  <td width="52" height="18" align="center"> 5-9 </td>
  <td width="52" height="18" align="center"> 10-14 </td>
  <td width="52" height="18" align="center"> 15+ </td>
  <td width="51" height="18" align="center"> &nbsp; </td>
</tr>
<tr>
  <td colspan="5" height="1" bgcolor="#000000"></td>
</tr>
<tr bgcolor="#CCCCCC">
  <td width="52" height="18" align="center"> Bruised </td>
  <td width="52" height="18" align="center"> Dazed </td>
  <td width="52" height="18" align="center"> Staggered </td>
  <td width="52" height="18" align="center"> Unconscious </td>
  <td width="51" height="18" align="center"> &nbsp; </td>
</tr>
<tr>
  <td colspan="5" height="1" bgcolor="#000000"></td>
</tr>
<tr>
  <td width="52" height="18" align="center"> &nbsp; </td>
  <td width="52" height="18" align="center"><img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/box.gif" width="11" height="11"></td>
  <td width="52" height="18" align="center"><img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/box.gif" width="11" height="11"></td>
  <td width="52" height="18" align="center"><img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/box.gif" width="11" height="11"></td>
  <td width="51" height="18" align="center"> &nbsp; </td>
</tr>
<tr>
  <td width="52" height="18" align="center"> &nbsp; </td>
  <td width="52" height="18" align="center"><img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/box.gif" width="11" height="11"></td>
  <td width="52" height="18" align="center"><img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/box.gif" width="11" height="11"></td>
  <td width="52" height="18" align="center"><img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/box.gif" width="11" height="11"></td>
  <td width="51" height="18" align="center"><img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/box.gif" width="11" height="11"></td>
</tr>
<tr>
  <td colspan="5" height="1" bgcolor="#000000"></td>
</tr>
<tr bgcolor="#CCCCCC">
  <td width="52" height="18" align="center"> Hurt </td>
  <td width="52" height="18" align="center"> Wounded </td>
  <td width="52" height="18" align="center"> Disabled </td>
  <td width="52" height="18" align="center"> Dying </td>
  <td width="51" height="18" align="center"> Dead </td>
</tr>
</table>
<!-- end of Damage Track subtable -->
      </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Alignment </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" border="0" align="center"> $char->{'Alignment'} </td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td colspan="9" width="221" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Calling </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" border="0" align="center"> $char->{'Calling'} </td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td colspan="9" width="221" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Light Nature </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" border="0" align="center"> $char->{'LightNature'} </td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td colspan="9" width="221" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Shadow Nature </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" border="0" align="center"> $char->{'ShadowNature'} </td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td class="minorHeading" colspan="9" width="221" height="14" align="center">
        Wealth and Reputation
      </td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Wealth </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" border="0" align="center"> $char->{'Wealth'} </td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td colspan="9" width="221" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Profession </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" border="0" align="center"> $char->{'Profession'} </td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td colspan="9" width="221" height="1" bgcolor="#000000"></td>
    </tr>
    <tr>
      <!-- 7 columns of damage subtable 259 => 221 left -->
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td class="statHeading" width="74" height="14" align="center">
        Reputation </td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td colspan="6" width="145" height="14" border="0" align="center"> $char->{'Reputation'} </td>
    </tr>
    </table>
    <!-- end of statistics subtable -->
  </td>
</tr>
<tr>
  <td width="480" align="center">
    <!-- start of weapons subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="0">
    <tr>
      <td colspan="8" class="majorHeading" width="480" height="18" align="center">
        <big>W</big>EAPONS </td>
    </tr>
    <tr>
      <td colspan="2" class="minorHeading" width="165" height="14" align="center">
        Weapon </td>
      <td colspan="2" class="minorHeading" width="105" height="14" align="center">
        Attack Bonus </td>
      <td colspan="2" class="minorHeading" width="105" height="14" align="center">
        Damage Bonus </td>
      <td colspan="2" class="minorHeading" width="105" height="14" align="center">
        Range </td>
    </tr>
    <tr bgcolor="#CCCCCC">
      <td width="164" height="14" align="center">$char->{'Weapon_1_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_1_AttackBonus'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_1_DamageBonus'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_1_Range'}</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="8" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td width="164" height="14" align="center">$char->{'Weapon_2_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_2_AttackBonus'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_2_DamageBonus'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_2_Range'}</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="8" bgcolor="#000000" height="1"></td>
    </tr>
    <tr bgcolor="#CCCCCC">
      <td width="164" height="14" align="center">$char->{'Weapon_3_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_3_AttackBonus'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_3_DamageBonus'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="104" height="14" align="center">$char->{'Weapon_3_Range'}</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    </table>
    <!-- end of weapons subtable -->
  </td>
</tr>
<tr>
  <td width="480" align="center">
    <!-- start of skills subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="0">
    <tr>
      <td colspan="12" class="majorHeading" width="480" height="18" align="center">
        <big>S</big>KILLS </td>
    </tr>
    <tr>
      <td colspan="2" class="minorHeading" width="120" height="14" align="center">
        Skill </td>
      <td colspan="2" class="minorHeading" width="40" height="14" align="center">
        Bonus </td>
      <td colspan="2" class="minorHeading" width="120" height="14" align="center">
        Skill </td>
      <td colspan="2" class="minorHeading" width="40" height="14" align="center">
        Bonus </td>
      <td colspan="2" class="minorHeading" width="120" height="14" align="center">
        Skill </td>
      <td colspan="2" class="minorHeading" width="40" height="14" align="center">
        Bonus </td>
    </tr>
    <tr>
      <td width="119" height="14" align="center">$char->{'Skill_1_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_1_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_1_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_6_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_6_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_6_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_11_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_11_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_11_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="12" bgcolor="#000000" height="1"></td>
    </tr>
    <tr bgcolor="#CCCCCC">
      <td width="119" height="14" align="center">$char->{'Skill_2_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_2_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_2_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_7_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_7_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_7_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_12_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_12_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_12_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="12" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td width="119" height="14" align="center">$char->{'Skill_3_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_3_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_3_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_8_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_8_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_8_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_13_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_13_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_13_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="12" bgcolor="#000000" height="1"></td>
    </tr>
    <tr bgcolor="#CCCCCC">
      <td width="119" height="14" align="center">$char->{'Skill_4_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_4_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_4_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_9_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_9_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_9_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_14_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_14_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_14_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="12" bgcolor="#000000" height="1"></td>
    </tr>
    <tr>
      <td width="119" height="14" align="center">$char->{'Skill_5_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_5_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_5_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_10_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_10_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_10_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="119" height="14" align="center">$char->{'Skill_15_Name'}</td>
      <td width="1" height="14" bgcolor="#000000" align="center"></td>
      <td width="39" height="14" align="right">$char->{'Skill_15_Value'}
        <img src="http://www.darkshire.net/jhkim/rpg/bluerose/img/minibox$char->{'Skill_15_Favored'}.gif" width="7" height="7">&nbsp;</td>
      <td width="1" height="14" bgcolor="#FFFFFF" align="center"></td>
    </tr>
    <tr>
      <td colspan="12" bgcolor="#000000" height="1"></td>
    </tr>
    </table>
    <!-- end of skills subtable -->
  </td>
</tr>
<tr valign="top">
  <td width="480" align="center">
    <!-- start of arcana/feats/etc table -->
    <table class="standard" border="0" cellpadding="0" cellspacing="0">
    <tr>
      <td class="majorHeading" width="230" height="18" align="center">
        <big>A</big>RCANA </td>
      <td rowspan="4" width="20" height="18" align="center"> &nbsp; </td>
      <td class="majorHeading" width="230" height="18" align="center">
        <big>F</big>EATS </td>
    </tr>
    <tr>
      <td width="230" height="60" align="left" valign="top">
$char->{'Arcana'}
      </td>
      <td width="230" height="60" align="left" valign="top">
$char->{'Feats'}
      </td>
    </tr>
    <tr>
      <td class="majorHeading" width="230" height="18" align="center">
        <big>S</big>PECIAL <b>A</b>BILITIES </td>
      <td class="majorHeading" width="230" height="18" align="center">
        <big>E</big>QUIPMENT </td>
    </tr>
    <tr>
      <td width="230" height="60" align="left" valign="top">
$char->{'SpecialAbilities'}
      </td>
      <td width="230" height="60" align="left" valign="top">
$char->{'Equipment'}
      </td>
    </tr>
    </table>
    <!-- end of arcana/feats/etc table -->
  </td>
</tr>
</table>
</body></html>
EndDefaultDocument
}

########################################################################
sub print_xml_style {
    my ($char,$req) = @_;

    $char->validate();

    foreach ($char->stats()) {
	# make sure string fields are XML-valid
	$char->{$_} =~ s/&/&amp;/g;
	$char->{$_} =~ s/</&lt;/g;
	$char->{$_} =~ s/>/&gt;/g;
	# remove plus signs which are not properly processed by the xsl
	$char->{$_} =~ s/^\s*\+(\d+)\s*$/$1/;
    }
    $char->{'Speed'} =~ s|\s*ft\.?\s*|<feet/>|;

    # compose the skills block
    my $skills;
    foreach my $i (1..28) {
	my $name = $char->{'Skill_'.$i.'_Name'};
	my $ability = lc( $char->{'Skill_'.$i.'_Ability'} );
	$skills .= "\t\t<skill name=\"$name\" ability=\"$ability\">";
	$skills .= "<untrained/>" if ($char->{'Skill_'.$i.'_'});
	$skills .= "<favoured/>" if ($char->{'Skill_'.$i.'_Favored'});
	$skills .= "<known/>" if ($char->{'Skill_'.$i.'_Known'});
	$skills .= "<bonus>".$char->{'Skill_'.$i.'_Modifier'}."</bonus>" 
	    if ($char->{'Skill_'.$i.'_Modifier'} =~ s/^\s*\+?(\-?\d+)\s*$/$1/);
	$skills .= "</skill>\n";
    }
    # compose the weapons block
    my $weapons;
    foreach my $i (1..10) {
	next unless ($char->{'Weapon_'.$i.'_Name'} =~ m/\S/);

	my $attack = $char->{'Weapon_'.$i.'_AttackBonus'};
	$attack =~ s/^\+//;
	my $damage = $char->{'Weapon_'.$i.'_DamageBonus'};
	$damage =~ s/^\+//;
	my $range = $char->{'Weapon_'.$i.'_Range'};
	$range =~ s|\s+ft\.?||;

	### Add in the XML block
	$weapons .= "\t\t<weapon>\n";
	$weapons .= "\t\t\t<name>".$char->{'Weapon_'.$i.'_Name'}."</name>\n";
	$weapons .= "\t\t\t<damage>".$damage."</damage>\n";
	$weapons .= "\t\t\t<crit>".$char->{'Weapon_'.$i.'_Critical'}."</crit>\n";
	$weapons .= "\t\t\t<weight>".$char->{'Weapon_'.$i.'_Weight'}."</weight>\n";
	$weapons .= "\t\t\t<type>".$char->{'Weapon_'.$i.'_WeaponType'}."</type>\n";
	$weapons .= "\t\t\t<size>".$char->{'Weapon_'.$i.'_WeaponSize'}."</size>\n";
	$weapons .= "\t\t\t<bonus>".$attack."<tohit/></bonus>\n";
	$weapons .= "\t\t\t<hand/>\n" if ($char->{'Weapon_'.$i.'_IsHand'});
	$weapons .= "\t\t\t<ranged/>\n" if ($char->{'Weapon_'.$i.'_IsRanged'});
	$weapons .= "\t\t\t<cha/>\n" if ($char->{'Weapon_'.$i.'_CharismaBased'});
	$weapons .= "\t\t\t<int/>\n" if ($char->{'Weapon_'.$i.'_IntelligenceBased'});
	$weapons .= "\t\t\t<wis/>\n" if ($char->{'Weapon_'.$i.'_WisdomBased'});

	$weapons .= "\t\t\t<range>".$range."</range>\n" if ($range);
	$weapons .= "\t\t\t<special>".$char->{'Weapon_'.$i.'_SpecialNotes'}."</special>\n" 
	    if ($char->{'Weapon_'.$i.'_SpecialNotes'});
	$weapons .= "\t\t</weapon>\n";
    }
    
    # print with Content-Type: application/xml
    print $req->header('application/xml');
print <<"EndXmlDocument";
<?xml version="1.0"?>
<?xml-stylesheet href="bluerose.xsl" type="text/xsl"?>
<character>
	<name>$char->{'CharacterName'}</name>
	<player>$char->{'PlayerName'}</player>
	<role>$char->{'CharacterRole'} <level>$char->{'CharacterLevel'}</level></role>
	<race>$char->{'CharacterBackground'}</race>
	<alignment>$char->{'Alignment'}</alignment>
	<natures>
		<light>$char->{'LightNature'}</light>
		<shadow>$char->{'ShadowNature'}</shadow>
		<calling>$char->{'Calling'}</calling>
	</natures>
	<size>$char->{'Size'}</size>
	<age></age>
	<gender></gender>
	<height></height>
	<weight></weight>
	<eyes></eyes>
	<hair></hair>
	<skin></skin>

	<speed>$char->{'Speed'}</speed>

	<abilities>
		<ability name="strength">$char->{'Ability_Strength_Value'}</ability>
		<ability name="dexterity">$char->{'Ability_Dexterity_Value'}</ability>
		<ability name="constitution">$char->{'Ability_Constitution_Value'}</ability>
		<ability name="intelligence">$char->{'Ability_Intelligence_Value'}</ability>
		<ability name="wisdom">$char->{'Ability_Wisdom_Value'}</ability>
		<ability name="charisma">$char->{'Ability_Charisma_Value'}</ability>
	</abilities>

	<health>
		<bash>
			<taken>0</taken>
			<levels>4</levels>
		</bash>
		<lethal>
			<taken>0</taken>
			<levels>5</levels>
		</lethal>
	</health>
	
	<bab>$char->{'BaseAttackBonus'}</bab>
	<def>$char->{'DefenseBonus'}</def>

	<wealth>$char->{'Wealth'}</wealth>
	
	<saves>
		<save name="toughness" ability="constitution">$char->{'SavingThrow_Toughness_Value'}</save>
		<save name="fortitude" ability="constitution">$char->{'SavingThrow_Fortitude_Value'}</save>
		<save name="reflex" ability="dexterity">$char->{'SavingThrow_Reflex_Value'}</save>
		<save name="will" ability="wisdom">$char->{'SavingThrow_Will_Value'}</save>
	</saves>

	<skills>
		<!--skill name="name" ability="base ability"><untrained/><favoured/><known/><bonus>n</bonus></skill-->
		$skills
	</skills>

	<weapons>
		<!--weapon-->
			<!-- name>Longsword</name -->
			<!-- damage>3</damage -->
			<!-- crit>(19-20)x2</crit -->
			<!-- weight>4</weight -->
			<!-- type>SP</type -->
			<!-- size>M</size -->
			<!-- bonus>1<tohit/></bonus -->
			<!-- hand/ --> <!-- hand weapon -->
			<!-- ranged/--> <!-- Ranged weapon -->
			<!-- cha/--> <!-- Charisma-based attack -->
			<!-- int/--> <!-- intelligence-based attack -->
			<!-- wis/--> <!-- wisdom-based attack -->
			<!-- range>n</range--> <!-- Range increment -->
			<!-- special>text</special--> <!-- Special ability -->
		<!-- /weapon -->
$weapons
	</weapons>
	
	<armours>
		<worn>
			<armour>
				<name>Studded Leather</name>   <!-- Armour Name -->
				<bonus>3</bonus>       <!-- Adds to Defense -->
				<maxdodge>5</maxdodge>  <!-- Maximum Dodge for Defense -->
				<acpen>-1</acpen>        <!-- Armour Check Penalty.  Applies to some skills -->
				<speed>30</speed>        <!-- Maximum speed while wearing this armour -->
				<weight>20</weight>     <!-- Weight of the armour -->
			</armour>
		</worn>
		<unworn>
		</unworn>
	</armours>

	<feats>
		<!-- Feats -->
		<!--feat name="name"><description>blah</description><known>n</known></feat-->
		<!--Note: the XSL will test just known to display the feat -->
		<!--      the number, n, will be shown if it's there, otherwise, will be 0, I hope :p -->
		<category name="general">
			<feat name="accurate Attack"><description>Reduce your damage bonus to increase your attack bonus.</description></feat>
			<feat name="all-out Attack"><description>Reduce your defense bonus to increase your attack bonus.</description></feat>
			<feat name="arcane Balance"><description>You can walk across any surface without sinking</description></feat>
			<feat name="arcane Speed"><description>You can move with great speed in short bursts</description></feat>
			<feat name="arcane Strike"><description>Your unarmed strikes are considered arcane weapons</description></feat>
			<feat name="arcane Training"><description>You're trained in two arcana</description></feat>
			<feat name="arcane Weapon"><description>Your melee weapons are considered arcane weapons</description></feat>
			<feat name="arcanum"><description>You can use one arcanum without an Arcane Talent feat</description></feat>
			<feat name="armour Training"><known/><description>You know how to move and fight while wearing armour</description></feat>
			<feat name="beloved"><description>You have found true love</description></feat>
			<feat name="blind-fight"><description>Half miss chance while in melee combat</description></feat>
			<feat name="canny Defense"><description>Add your Int or Wis score to your Defense</description></feat>
			<feat name="comprehend"><description>You can understand the spoken language of any creature</description></feat>
			<feat name="defensive Attack"><description>Reduce your attack bonus to increase your dodge bonus</description></feat>
			<feat name="dodge"><description>+1 to your dodge bonus</description></feat>
			<feat name="endurance"><description>+4 bonus on stamina-related Con checks and Fort saves</description></feat>
			<feat name="exotic Weapon Training"><description>You're trained in a particular exotic weapon</description></feat>
			<feat name="far Shot"><description>Increase range increment by one-half (double for thrown weapons)</description></feat>
			<feat name="favours"><description>You know people who can help you out from time to time</description></feat>
			<feat name="fortune's Favour"><description>Add your Cha score to your saving throws</description></feat>
			<feat name="great Fortitude"><description>+2 on Fortitude saving throws</description></feat>
			<feat name="great Toughness"><description>+1 on Toughness saving throws</description></feat>
			<feat name="heirloom"><description>You have some inheritance left to you</description></feat>
			<feat name="immunity to Disease"><description>You are immune to all diseases</description></feat>
			<feat name="immunity to Poison"><description>You are immune to all poisons</description></feat>
			<feat name="improved Balance"><description>No penalty for accelerated movement while balancing</description></feat>
			<feat name="improved Climb"><description>No penalty for accelerated movement while climbing</description></feat>
			<feat name="improved Critical"><description>Your threat range with a particular attack is doubled</description></feat>
			<feat name="improved Demoralize"><description>You can make an Intimidate check as a move action</description></feat>
			<feat name="improved Disarm"><description>+2 bonus when attempting to disarm an opponent</description></feat>
			<feat name="improved Dodge"><description>+2 bonus when taking the dodge action</description></feat>
			<feat name="improved Feint"><description>You can feint as a move action</description></feat>
			<feat name="improved Grab"><description>You can follow an unarmed attack with a free grapple</description></feat>
			<feat name="improved Initiative"><known/><description>You get a +4 bonus on initiative checks</description></feat>
			<feat name="improved Precise Shot"><description>No penalty for less than total cover or concealment</description></feat>
			<feat name="improved Ranged Disarm"><description>No penalty when making a ranged disarm attempt</description></feat>
			<feat name="improved Speed"><description>+10 feet movement speed</description></feat>
			<feat name="improved Strike"><description>You do Lethal damage unarmed</description></feat>
			<feat name="improved Sunder"><description>+4 to hit when striking held objects</description></feat>
			<feat name="improved Trip"><description>+2 bonus to trip opponents</description></feat>
			<feat name="improved Uncanny Dodge"><description>You cannot be flanked</description></feat>
			<feat name="iron Will"><description>+2 bonus on Will saving throws</description></feat>
			<feat name="lightning Reflexes"><description>+2 bonus on Reflex saving throws</description></feat>
			<feat name="low-light Vision"><description>See twice as far in low-light conditions</description></feat>
			<feat name="mounted Archery"><description>Half penalty when using ranged weapons while mounted</description></feat>
			<feat name="mounted Combat"><description>Substitute Ride check for mount's Defense</description></feat>
			<feat name="on the Run"><description>Move both before and after your standard action</description></feat>
			<feat name="point Blank Shot"><description>+1 attack and damage with ranged weapons at 30' range</description></feat>
			<feat name="power Attack"><description>Reduce your attack bonus to increase your damage</description></feat>
			<feat name="precise Shot"><description>You can make ranged attacks into melee with no penalty</description></feat>
			<feat name="pure-Hearted"><description>+4 bonus on saves to resist corruption</description></feat>
			<feat name="ranged Pin"><description>You can pin an opponent with a ranged weapon</description></feat>
			<feat name="rhy-bonded"><description>You have a psychic bond to a companion</description></feat>
			<feat name="ride-by Attack"><description>While mounted you can move before and after a standard action</description></feat>
			<feat name="run"><description>You run at 5 times your normal speed</description></feat>
			<feat name="second Chance"><description>You get a second save against a particular hazard</description></feat>
			<feat name="self-Healing"><description>You can use Body Control to heal yourself</description></feat>
			<feat name="sensitive"><description>+2 bonus on interaction skills with intelligent creatures</description></feat>
			<feat name="shield Training"><description>You're trained in the proper use of shields in combat</description></feat>
			<feat name="skill Affinity"><description>Add two skills to your list of favoured skills</description></feat>
			<feat name="skill Focus"><description>+3 bonus with a chosen skill</description></feat>
			<feat name="skill Training"><description>Add two skills to your list of known skills</description></feat>
			<feat name="talented"><description>+2 with two related skills</description></feat>
			<feat name="taunt"><description>Make a Bluff check to shake a target's confidence</description></feat>
			<feat name="track"><known/><description>You can find and follow tracks</description></feat>
			<feat name="trackless Step"><description>You leave no trail in natural surroundings</description></feat>
			<feat name="trample"><description>You can overrun very effectively while mounted</description></feat>
			<feat name="two-weapon Defense"><description>Your two-weapon fighting style improves your Defense</description></feat>
			<feat name="two-weapon Fighting"><description>You can skillfully fight with a weapon in each hand</description></feat>
			<feat name="uncanny Dodge"><description>You retain your dodge bonus when flat-footed</description></feat>
			<feat name="wealthy"><description>+3 Wealth bonus</description></feat>
			<feat name="weapon Finesse"><description>Add your Dex score in place of your Str score with a light weapon</description></feat>
			<feat name="weapon Training"><known/><description>You're trained in the use of martial weapons</description></feat>
			<feat name="wild Empathy"><description>You can use Handle Animal as an interaction skill</description></feat>
			<feat name="wild Talent"><description>You have a strong wild talent with a particular type of arcana</description></feat>
			<feat name="wildwalk"><description>You can more through natural surroundings freely</description></feat>
		</category>
		<category name="Arcane">
			<feat name="animism Talent"><description>You can learn Animism Arcana</description></feat>
			<feat name="arcane Focus"><description>+1 to the save Difficulty of your arcana of one talent</description></feat>
			<feat name="brew Elixir"><description>You can brew arcane elixirs</description></feat>
			<feat name="cure Blindness/Deafness"><description>You can cure vision or hearing loss</description></feat>
			<feat name="cure Disease"><description>You can cure disease</description></feat>
			<feat name="cure Poison"><description>You can neutralize the effects of poison</description></feat>
			<feat name="deflect Arrows"><description>You can deflect one ranged attack against you per round</description></feat>
			<feat name="empower Arcana"><description>Increase the effective rank of your arcana</description></feat>
			<feat name="erase Signature"><description>You can erase arcane signatures</description></feat>
			<feat name="familiar"><description>You have a psychic bond with a special animal companion</description></feat>
			<feat name="greater Arcane Focus"><description>Additional +1 Difficulty on the saves of one arcane talent</description></feat>
			<feat name="healing Talent"><description>You can learn healing arcana</description></feat>
			<feat name="imbue Life"><description>You can restore life to the dead</description></feat>
			<feat name="imbue Stone"><description>You can empower arcane stones</description></feat>
			<feat name="imbue Unlife"><description>You can create unliving creatures</description></feat>
			<feat name="imbue Weapon"><description>You can make masterwork weapons into arcane weapons</description></feat>
			<feat name="meditative Talent"><description>You can learn meditative arcana</description></feat>
			<feat name="psychic Shield Penetration"><description>+2 bonus to overcome a target's Psychic Shield</description></feat>
			<feat name="psychic Talent"><description>You can learn psychic arcana</description></feat>
			<feat name="psychic Weapon"><description>You can create a melee weapon out of psychic energy</description></feat>
			<feat name="purifying Light"><description>You can weild light as a weapon against Shadow</description></feat>
			<feat name="quicken Arcana"><description>Reduce the time required to use arcana</description></feat>
			<feat name="shaping Talent"><description>You can learn shaping arcana</description></feat>
			<feat name="subtle Arcana"><description>You can mute the signature of your arcana</description></feat>
			<feat name="summon Darkfiend"><description>you can summon darkfiends from Shadow</description></feat>
			<feat name="summon Elemental"><description>You can summon elementals from nature</description></feat>
			<feat name="truth Reading"><description>You can sense when someone is lying</description></feat>
			<feat name="visionary Talent"><description>You can learn visionary arcana</description></feat>
			<feat name="widen Arcana"><description>Affect an area with arcana</description></feat>
		</category>
		<category name="Expert">
			<feat name="crippling Strike"><description>Your surprise attacks inflict 1 point of Str damage</description></feat>
			<feat name="deflect Arrows"><description>You can deflectone ranged attack against you per turn</description></feat>
			<feat name="evasion"><description>No damage from attacks if you make your Reflex safe</description></feat>
			<feat name="fascinate"><description>You can capture and hold a person's attention</description></feat>
			<feat name="improved Evasion"><description>No damage on a successful Reflex save, half on a failed save</description></feat>
			<feat name="improvised Tools"><description>No penalty for using a skill without the proper tools</description></feat>
			<feat name="inspire"><description>You can inspire others with your presence</description></feat>
			<feat name="jack of All Trades"><description>You may use any skill untrained</description></feat>
			<feat name="master Plan"><description>Gain a bonus when you have a chance to prepare</description></feat>
			<feat name="skill Mastery"><description>Choose 5 skills you can take 10 with even under pressure</description></feat>
			<feat name="slow Fall"><description>You can slow your fall by 10' per two levels</description></feat>
			<feat name="stunning Attack"><description>You can make a stunning attack in melee</description></feat>
			<feat name="suggest"><description>You can plant suggestions into theminds of others</description></feat>
			<feat name="surprise Attack"><description>+2 damage with a surprise attack</description></feat>
			<feat name="trapfinding"><description>You can use Search to find hidden traps</description></feat>
		</category>
		<category name="Martial">
			<feat name="cleave"><description>Get an extra melee attack when you take out an opponent</description></feat>
			<feat name="diehard"><description>You automatically succed on Con checks to stabalize</description></feat>
			<feat name="favoured Foe"><description>+2 bonus against a particular type of foe</description></feat>
			<feat name="finishing Blow"><description>You can perform a coup de grace as a standard action</description></feat>
			<feat name="great Cleave"><description>Like Cleave, but usable an unlimited number of times</description></feat>
			<feat name="greater Weapon Focus"><description>+1 bonus on attack rolls with a chosen weapon</description></feat>
			<feat name="greater Weapon Specialization"><description>+2 bonus on damage with a chosen weapon</description></feat>
			<feat name="rage"><description>You can go into rage in combat</description></feat>
			<feat name="smite Foe"><description>You can inflict additional damage on your favoured foe</description></feat>
			<feat name="stunning Attack"><description>You can make a stunning attack in melee</description></feat>
			<feat name="weapon Focus (Longsword)"><known/><description>+1 on attack rolls with a chosen weapon</description></feat>
			<feat name="weapon Focus"><description>+1 on attack rolls with a chosen weapon</description></feat>
			<feat name="weapon Specialization"><description>+2 damage with a chosen weapon</description></feat>
		</category>
	</feats>

	<equipment>
		<!--item>Comm Widget</item-->
		<item name="Horse"><weight>0</weight></item>
		<item name="Backpack"><weight>2</weight></item>
		<item name="Bedroll"><weight>5</weight></item>
		<item name="Winter Blanket"><weight>3</weight></item>
		<item name="Silk Rope"><weight>5</weight></item>
		<item name="Waterskin"><weight>4</weight></item>
		<item name="Traveller's Outfit"><weight>5</weight></item>
	</equipment>

	<arcana>
		<!--arcanum name="name" ability="ability"><sorcery/><fatigue/><untrained/><known/><bonus>n</bonus></arcanum-->
		<talent name="all">  <!-- Any arcane Talent feat will grant this category as well as its own -->
			<!--talent /--> <!-- Indicates talent this category of Arcana. -->
			<arcanum name="psychic Shield" ability="wisdom"><untrained/></arcanum>
			<arcanum name="second Sight" ability="wisdom"><untrained/></arcanum>
		</talent>	
		<talent name="animism">
			<arcanum name="beast Link" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="beast Messenger" ability="none"></arcanum>
			<arcanum name="beast Reading" ability="wisdom"><untrained/></arcanum>
			<arcanum name="beast Speech" ability="none"></arcanum>
			<arcanum name="beast summoning" ability="charisma"><fatigue/></arcanum>
			<arcanum name="beast Trance" ability="charisma"></arcanum>
			<arcanum name="dominate Beast" ability="charisma"><sorcery/><fatigue/></arcanum>
			<arcanum name="ehnance Self" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="enhance Senses" ability="wisdom"></arcanum>
			<arcanum name="gentle Beasts" ability="charisma"></arcanum>
			<arcanum name="nature Reading" ability="wisdom"></arcanum>
			<arcanum name="plant Shaping" ability="intelligence"><fatigue/></arcanum>
		</talent>
		<talent name="healing">
			<arcanum name="body Control" ability="wisdom"><untrained/></arcanum>
			<arcanum name="cure" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="drain vitality" ability="wisdom"><sorcery/></arcanum>
			<arcanum name="enhance Other" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="harm" ability="none"><sorcery/><fatigure/></arcanum>
			<arcanum name="pain" ability="charisma"><sorcery/><fatigure/></arcanum>
		</talent>
		<talent name="meditative">
			<arcanum name="battle Dance" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="body Control" ability="wisdom"><untrained/></arcanum>
			<arcanum name="ehnance Self" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="enhance Senses" ability="wisdom"></arcanum>
		</talent>
		<talent name="psychic">
			<arcanum name="bliss" ability="charisma"><fatigue/></arcanum>
			<arcanum name="calm" ability="charisma"></arcanum>
			<arcanum name="dominate" ability="charisma"><fatigue/></arcanum>
			<arcanum name="heart Reading" ability="wisdom"><untrained/></arcanum>
			<arcanum name="heart Shaping" ability="charisma"><fatigue/></arcanum>
			<arcanum name="illusion" ability="charisma"><fatigue/></arcanum>
			<arcanum name="mind Probe" ability="wisdom"><sorcery/><fatigue/></arcanum>
			<arcanum name="mind Reading" ability="wisdom"></arcanum>
			<arcanum name="mind Shaping" ability="wisdom"><sorcery/><fatigue/></arcanum>
			<arcanum name="mind Touch" ability="charisma"><untrained/></arcanum>
			<arcanum name="pain" ability="charisma"><sorcery/><fatigue/></arcanum>
			<arcanum name="psychic Blast" ability="charisma"><sorcery/><fatigue/></arcanum>
			<arcanum name="sense Minds" ability="wisdom"></arcanum>
			<arcanum name="sleep" ability="charisma"><fatigue/></arcanum>
			<arcanum name="suggestion" ability="charisma"><fatigue/></arcanum>
			<arcanum name="ward" ability="charisma"><fatigue/></arcanum>
		</talent>
		<talent name="shaping">
			<arcanum name="cold Shaping" ability="intelligence"><fatigue/></arcanum>
			<arcanum name="earth Shaping" ability="intelligence"><fatigue/></arcanum>
			<arcanum name="fire Shaping" ability="intelligence"><fatigue/></arcanum>
			<arcanum name="flesh Shaping" ability="intelligence"><sorcery/><fatigue/></arcanum>
			<arcanum name="light Shaping" ability="intelligence"><fatigue/></arcanum>
			<arcanum name="manipulate Object" ability="intelligence"><fatigue/></arcanum>
			<arcanum name="move Object" ability="intelligence"><fatigue/><untrained/></arcanum>
			<arcanum name="plant Shaping" ability="intelligence"><fatigue/></arcanum>
			<arcanum name="sorcerer's Grasp" ability="none"><sorcery/><fatigue/></arcanum>
			<arcanum name="water Shaping" ability="intelligence"><fatigue/></arcanum>
			<arcanum name="wind Shaping" ability="intelligence"><fatigue/></arcanum>
		</talent>
		<talent name="visionary">
			<arcanum name="battle Dance" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="enhance Senses" ability="wisdom"></arcanum>
			<arcanum name="object Reading" ability="wisdom"></arcanum>
			<arcanum name="scrying" ability="wisdom"><fatigue/></arcanum>
			<arcanum name="visions" ability="wisdom"><untrained/></arcanum>
		</talent>
	</arcana>
</character>
EndXmlDocument

}
########################################################################
